import React from 'react';
import cx from 'classnames';
import { View, Button, Block } from '@tarojs/components';
import { pxTransform } from '../../utils';
import HuiIcon from '../Icon/Icon';
const HuiButton = props => {
    const { size = 'medium', type = 'primary', color = '', loading = false, gradientColor, block = false, disabled = false, onClick, width, radiusType = 'default', style, prefixIcon, suffixIcon, extra, openType, children, className = '', onGetUserInfo, onGetPhoneNumber, onContact, onOpenSetting, onChooseAvatar, } = props;
    const buttonStyle = Object.assign({ width: width ? pxTransform(width) : undefined, background: type === 'secondary' ? undefined : gradientColor || color, borderColor: gradientColor ? 'unset' : color, color: ['secondary', 'text'].includes(type) ? color : undefined }, style);
    const handleClick = (e) => {
        if (!disabled && onClick) {
            onClick(e);
        }
    };
    const iconSizeMap = {
        'small': 13,
        'medium': 14,
        'large': 16,
    };
    const buttonDisabled = disabled || loading;
    const buttonContent = React.createElement(Block, null,
        prefixIcon
            && React.createElement(HuiIcon, { name: prefixIcon, style: { marginRight: pxTransform(8) }, size: iconSizeMap[size] }),
        React.createElement(View, { className: cx('content-wrapper', { hidden: loading }) },
            React.createElement(View, { className: 'button-text' }, children),
            extra && React.createElement(View, { className: 'extra' }, extra)),
        suffixIcon
            && React.createElement(HuiIcon, { name: suffixIcon, style: { marginLeft: pxTransform(8) }, size: iconSizeMap[size] }));
    return (React.createElement(Button, { openType: openType, onGetPhoneNumber: onGetPhoneNumber, onGetUserInfo: onGetUserInfo, onContact: onContact, onOpenSetting: onOpenSetting, 
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        onChooseAvatar: onChooseAvatar, style: buttonStyle, hoverClass: 'hover', disabled: buttonDisabled, onClick: handleClick, className: cx(`hui-button ${size} ${type} radius-${radiusType} ${className}`, { disabled: buttonDisabled }, { inline: !block }) },
        loading && React.createElement(View, { className: 'loading-area' }),
        buttonContent));
};
export default HuiButton;
//# sourceMappingURL=Button.js.map