var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useContext, forwardRef, useImperativeHandle } from 'react';
import cx from 'classnames';
import { View } from '@tarojs/components';
import CheckboxGroupContext from './context';
import HuiIcon from '../Icon/Icon';
import { pxTransform } from '../../utils';
const DEFAULT_ICON_COLOR = '#ed3737';
const DEFAULT_ICON_SIZE = 20;
const HuiCheckbox = (props, ref) => {
    const { value, size = DEFAULT_ICON_SIZE, disabled = false, checked = false, color = DEFAULT_ICON_COLOR, style, className = '', children, onClick } = props, rest = __rest(props, ["value", "size", "disabled", "checked", "color", "style", "className", "children", "onClick"]);
    const context = useContext(CheckboxGroupContext);
    const hasChildren = !!children;
    const finalDisabled = (context === null || context === void 0 ? void 0 : context.disabled) || disabled;
    const toggle = () => {
        var _a;
        const beforeCheckedList = (_a = context === null || context === void 0 ? void 0 : context.checkedList) !== null && _a !== void 0 ? _a : [];
        const afterCheckedList = checked
            ? beforeCheckedList.filter(item => item !== value)
            : beforeCheckedList.concat(value);
        context === null || context === void 0 ? void 0 : context.onChange(afterCheckedList);
    };
    const handleClick = e => {
        e.stopPropagation();
        if (!finalDisabled) {
            toggle();
            onClick && onClick(e);
        }
    };
    useImperativeHandle(ref, () => ({
        toggle: () => {
            if (!finalDisabled) {
                toggle();
            }
        },
    }));
    return (React.createElement(View, Object.assign({ style: style, ref: ref, className: cx(`hui-checkbox ${className}`, { 'disabled': finalDisabled }), onClick: handleClick }, rest),
        React.createElement(View, { className: cx('hui-checkbox-icon', { 'unchecked': !checked }), style: {
                width: pxTransform(size),
                height: pxTransform(size),
            } },
            React.createElement(HuiIcon, { name: '009-checkbox', size: size, color: checked ? color : 'transparent' })),
        hasChildren && (React.createElement(View, { className: 'hui-checkbox-content' }, children))));
};
export default forwardRef(HuiCheckbox);
//# sourceMappingURL=Checkbox.js.map