import React, { useEffect, useState } from 'react';
import cx from 'classnames';
import { View, Image } from '@tarojs/components';
import HuiButton from '../Button/Button';
import noData from '@/static/nosearch.png';
import failed from '../../static/failed.png';
const prefix = 'hui-default-page';
const defaultContent = {
    showButton: true,
    isImage: true,
    description: '暂无数据',
    info: '',
    buttonText: '看看其他',
    imageIcon: noData,
};
const DefaultPage = props => {
    const { className = '', type, visible = false, imageIcon, buttonProps, children, style, onClick, } = props;
    const [content, setContent] = useState(defaultContent);
    useEffect(() => {
        if (!type) {
            setContent(Object.assign({}, props));
            return;
        }
        switch (type) {
            case 'noData':
                setContent(defaultContent);
                break;
            case 'noSearch':
                setContent({
                    showButton: false,
                    isImage: true,
                    description: '找了一圈，啥也没找到',
                    info: '',
                    imageIcon: noData,
                });
                break;
            case 'failed':
                setContent({
                    showButton: true,
                    isImage: true,
                    description: '加载失败',
                    info: '重新再试一下吧',
                    imageIcon: failed,
                    buttonText: '重新加载',
                });
                break;
            default:
                setContent(defaultContent);
                break;
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [type]);
    const btnProps = Object.assign({ type: 'primary', size: 'medium', onClick }, buttonProps);
    const defaultPage = (React.createElement(View, { className: cx(prefix, className), style: style },
        React.createElement(View, { className: `${prefix}-padding` }),
        content.imageIcon && (React.createElement(View, { className: `${prefix}-image` }, content.isImage
            ? (React.createElement(Image, { src: content.imageIcon, className: `${prefix}-image-pic` }))
            : imageIcon)),
        content.description && React.createElement(View, { className: `${prefix}-description` }, content.description),
        content.info && React.createElement(View, { className: `${prefix}-info` }, content.info),
        content.showButton && props.showButton && (React.createElement(View, { className: `${prefix}-btn` },
            React.createElement(HuiButton, Object.assign({}, btnProps), content.buttonText)))));
    const childs = children !== null && children !== void 0 ? children : null;
    return visible ? defaultPage : childs;
};
DefaultPage.defaultProps = {
    visible: false,
    showButton: true,
    buttonText: '确认',
};
export default DefaultPage;
//# sourceMappingURL=DefaultPage.js.map