var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState } from 'react';
import { View, Image } from '@tarojs/components';
import cx from 'classnames';
import { ImageStatus, ImageSize } from './constants';
import HuiIcon from '../Icon/Icon';
import { pxTransform } from '../../utils';
const getIconName = (imageStatus) => {
    if (imageStatus === ImageStatus.Fail) {
        return '014-loadfailed';
    }
    if (imageStatus === ImageStatus.Empty) {
        return '122-defaultfill';
    }
    return '';
};
const HuiImage = props => {
    const { style: customStyle, width = 0, height = 0, src, animated, placeholderImg, placeholderIcon, wapperClassName = '', onLoad, onError } = props, rest = __rest(props, ["style", "width", "height", "src", "animated", "placeholderImg", "placeholderIcon", "wapperClassName", "onLoad", "onError"]);
    const [imageStatus, setImageStatus] = useState(src ? ImageStatus.Loading : ImageStatus.Empty);
    const defaultPlaceholderSize = width * 0.4;
    const customPlaceholderSize = width * 0.16;
    const iconName = getIconName(imageStatus);
    const handleOnLoad = (event) => {
        setImageStatus(ImageStatus.Success);
        onLoad && onLoad(event);
    };
    const handleOnError = (event) => {
        setImageStatus(ImageStatus.Fail);
        onError && onError(event);
    };
    const getImageStatusText = () => {
        if (imageStatus === ImageStatus.Empty)
            return '暂无图片';
        if (imageStatus === ImageStatus.Fail)
            return '加载失败';
        if (imageStatus === ImageStatus.Loading)
            return '加载中…';
        return '';
    };
    const getPlaceholder = () => {
        if (iconName) {
            return React.createElement(HuiIcon, { name: iconName, size: defaultPlaceholderSize });
        }
        if (placeholderIcon) {
            return React.createElement(HuiIcon, { name: placeholderIcon, size: customPlaceholderSize });
        }
        if (placeholderImg) {
            const placeholderImgSize = pxTransform(customPlaceholderSize);
            return React.createElement(Image, { mode: 'aspectFill', src: placeholderImg, style: { width: placeholderImgSize, height: placeholderImgSize } });
        }
        return '';
    };
    /**
     * 当未传入width或height时，加载状态展示为色块+动画效果
     * 当图片宽或者高小于60px，加载状态仅展示为色块
     * 当图片宽或者高小于86px，加载状态仅展示为文字
     * 当图片宽和高都大于86px，加载状态展示为图文
     */
    const getImageSize = () => {
        if (height && width) {
            return width < 60 || height < 60
                ? ImageSize.SMALL : width < 86 || height < 86
                ? ImageSize.MEDIUM : ImageSize.LARGE;
        }
        return ImageSize.SMALL;
    };
    const imageSize = getImageSize();
    const showAnimation = animated || !height || !width;
    const style = Object.assign(height && width ? { height: pxTransform(height), width: pxTransform(width) } : {}, customStyle);
    return (React.createElement(View, { className: `hui-image ${wapperClassName}`, style: style },
        imageStatus !== ImageStatus.Success && (React.createElement(View, { className: cx('placeholder', { 'shine': imageStatus === ImageStatus.Loading && showAnimation }) },
            imageSize === ImageSize.LARGE ? getPlaceholder() : null,
            imageSize === ImageSize.LARGE && imageStatus === ImageStatus.Loading && React.createElement(View, { className: 'loading-text' }, "\u52A0\u8F7D\u4E2D\u2026"),
            imageSize === ImageSize.MEDIUM ? getImageStatusText() : null)),
        src && (React.createElement(Image, Object.assign({ src: src, className: 'image', onLoad: handleOnLoad, onError: handleOnError }, rest)))));
};
HuiImage.defaultProps = {
    animated: false,
    mode: 'aspectFit',
};
export default HuiImage;
//# sourceMappingURL=Image.js.map