import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import cx from 'classnames';
import { addOpacityToHexColor, pxTransform } from '../../utils';
import HuiIcon from '../Icon';
const DEFAULT_ICON_SIZE = 18;
const DEFAULT_HOME_PAGE_PATH = '/pages/Index/Index';
var ThemeColor;
(function (ThemeColor) {
    ThemeColor["Black"] = "#000000";
    ThemeColor["White"] = "#ffffff";
})(ThemeColor || (ThemeColor = {}));
const HuiNavBar = props => {
    const { transparent, title, hideBack, showHome, button, opacity, style, className = '', theme, homepagePath = DEFAULT_HOME_PAGE_PATH, beforeNavBack, beforeBackToHome, } = props;
    const showBack = !hideBack && Taro.getCurrentPages().length > 1;
    const showCapsule = !button && (showBack || showHome);
    const showBorder = showHome;
    const { top, bottom, height } = Taro.getMenuButtonBoundingClientRect();
    const handleBackToHome = async () => {
        const canBackToHome = typeof beforeBackToHome === 'function'
            ? await beforeBackToHome()
            : true;
        if (!canBackToHome) {
            return;
        }
        Taro.reLaunch({
            url: homepagePath,
        });
    };
    const handleBack = async () => {
        const canBack = typeof beforeNavBack === 'function'
            ? await beforeNavBack()
            : true;
        if (!canBack) {
            return;
        }
        Taro.navigateBack();
    };
    const backgroundColor = theme === 'black' ? ThemeColor.Black : ThemeColor.White;
    const fontColor = theme === 'black' ? ThemeColor.White : ThemeColor.Black;
    return (React.createElement(View, { className: cx(`hui-nav-bar ${className}`, { transparent }), style: Object.assign({ height: `calc(${pxTransform(bottom)} + ${pxTransform(6)})`, paddingTop: `calc(${pxTransform(top)} - ${pxTransform(6)})`, backgroundColor: transparent
                ? addOpacityToHexColor(backgroundColor, opacity)
                : backgroundColor }, style) },
        React.createElement(View, { className: 'hui-nav-bar-content', style: { height: pxTransform(height) } },
            !!button && React.createElement(View, { className: 'hui-nav-bar-custom-button' }, button),
            showCapsule && (React.createElement(View, { className: cx('hui-nav-bar-capsule', { 'with-border': showBorder }), style: { color: fontColor } },
                showBack && (React.createElement(View, { className: 'hui-nav-bar-back', onClick: handleBack },
                    React.createElement(HuiIcon, { name: '011-left', size: DEFAULT_ICON_SIZE }))),
                (showBack && showHome) && React.createElement(View, { className: 'hui-nav-bar-divider' }),
                showHome && (React.createElement(View, { className: 'hui-nav-bar-back-home', onClick: handleBackToHome },
                    React.createElement(HuiIcon, { name: '078-homefill', size: DEFAULT_ICON_SIZE, color: fontColor }))))),
            title && (React.createElement(View, { className: 'hui-nav-bar-title', style: { color: fontColor } }, title)))));
};
const OPACITY_CHANGE_SCROLL_UPPER = 100;
const OPACITY_CHANGE_SCROLL_RANGE = 60;
export const getOpacityChangeHandlerGenerator = (e, cb, opacityChangeScrollOption = {}) => {
    const { upper = OPACITY_CHANGE_SCROLL_UPPER, range = OPACITY_CHANGE_SCROLL_RANGE, } = opacityChangeScrollOption;
    let opacity = Math.max(e.detail.scrollTop - upper, 0)
        / range;
    if (opacity > 1) {
        opacity = 1;
    }
    else {
        opacity = Number(opacity.toFixed(1));
    }
    cb(opacity);
};
HuiNavBar.defaultProps = {
    transparent: false,
    title: '',
    hideBack: false,
    showHome: false,
    button: null,
    opacity: 1,
    theme: 'black',
    homepagePath: DEFAULT_HOME_PAGE_PATH,
};
export default HuiNavBar;
//# sourceMappingURL=index.js.map