import { View } from '@tarojs/components';
import cx from 'classnames';
import React, { useState, useEffect } from 'react';
import Taro from '@tarojs/taro';
import HuiIcon from '../Icon/Icon';
import { addOpacityToHexColor } from '../../utils';
const FONT_SIZE = 14;
const NoticeBar = props => {
    const { speed = 80, visible = true, color = '', hasIcon = false, type = 'default', onGotoMore, onClose, style, className = '', children, } = props;
    const [duration, setDuration] = useState(0);
    useEffect(() => {
        if (type === 'marquee' && children) {
            setDuration((Taro.getSystemInfoSync().windowWidth + children.toString().length * FONT_SIZE) / speed);
        }
    }, [type, children, speed]);
    const noticeBarStyle = Object.assign({ color, background: addOpacityToHexColor(color, 0.1) }, style);
    const handleClose = (e) => {
        if (type === 'close' && onClose) {
            onClose(e);
        }
    };
    const handleGoToMore = (e) => {
        if (type === 'more' && onGotoMore) {
            onGotoMore(e);
        }
    };
    return (visible ? (React.createElement(View, { className: cx(`hui-noticebar ${className}`, { marquee: type === 'marquee' }), style: noticeBarStyle, onClick: handleGoToMore },
        React.createElement(View, { className: 'hui-noticebar-content' },
            hasIcon && (React.createElement(View, { className: 'hui-noticebar-content-icon' },
                React.createElement(HuiIcon, { name: '011-notice', size: 16 }))),
            React.createElement(View, { className: 'hui-noticebar-content-text' },
                React.createElement(View, { className: cx('hui-noticebar-content-inner', {
                        'no-icon-width': !hasIcon && type !== 'marquee',
                        'icon-width': hasIcon && type !== 'marquee',
                        'max-width': type === 'default',
                    }), style: { animationDuration: `${duration}s` } }, children))),
        type === 'close' && (React.createElement(View, { className: 'hui-noticebar-close', onClick: handleClose },
            React.createElement(HuiIcon, { name: '006-close3', size: 16 }))),
        type === 'more' && (React.createElement(View, { className: 'hui-noticebar-more' },
            React.createElement(HuiIcon, { name: '012-arrowright', size: 16 }))))) : null);
};
export default NoticeBar;
//# sourceMappingURL=NoticeBar.js.map