import { View, PickerView, PickerViewColumn } from '@tarojs/components';
import cx from 'classnames';
import React, { useState, useEffect, useRef } from 'react';
import Taro from '@tarojs/taro';
import HuiDivider from '../Divider';
const handleTouchMove = (e) => {
    e.stopPropagation();
    e.preventDefault();
};
const prefix = 'hui-picker';
// eslint-disable-next-line @typescript-eslint/no-empty-function
const empty = () => { };
const Picker = props => {
    const { className, style, visible = false, onClose, title, cancelText = '取消', cancelStyle, confirmStyle, confirmText = '确定', current = [], columns = [], onChange = empty, onConfirm = empty, } = props;
    const [isOpened, setIsOpened] = useState(false);
    const valueRef = useRef(current);
    const rootClass = cx(className, prefix, {
        [`${prefix}-active`]: isOpened,
    });
    useEffect(() => {
        setIsOpened(visible);
        if (!visible) {
            doClose();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [visible]);
    const doClose = (e) => {
        if ('visible' in props && typeof onClose === 'function') {
            onClose(e);
        }
    };
    const handleClose = e => {
        setIsOpened(false);
        doClose(e);
    };
    const handleChange = e => {
        const value = e.detail.value;
        if (valueRef.current.length === 0) {
            valueRef.current = Array(value.length).fill(0);
        }
        let changedColumn;
        value.some((_, i) => {
            if (value[i] !== valueRef.current[i]) {
                changedColumn = i;
                return true;
            }
            return false;
        });
        valueRef.current = value;
        onChange(value, changedColumn);
    };
    return (React.createElement(View, { className: rootClass, style: style, onTouchMove: handleTouchMove },
        React.createElement(View, { onClick: handleClose, className: `${prefix}-mask` }),
        React.createElement(View, { className: `${prefix}-container` },
            React.createElement(View, { className: `${prefix}-content` },
                React.createElement(View, { className: `${prefix}-header` },
                    cancelText && (React.createElement(View, { className: `${prefix}-header-cancel`, style: cancelStyle, onClick: onClose }, cancelText)),
                    title && React.createElement(View, { className: `${prefix}-header-title` }, title),
                    confirmText && (React.createElement(View, { className: `${prefix}-header-confirm`, style: confirmStyle, onClick: () => onConfirm(valueRef.current) }, confirmText))),
                React.createElement(HuiDivider, null),
                React.createElement(View, { className: `${prefix}-body` },
                    React.createElement(PickerView, { indicatorStyle: 'height: 50px', style: { width: '100%', height: Taro.pxTransform(250) }, value: valueRef.current, onChange: handleChange }, columns.map((option, i) => (React.createElement(PickerViewColumn, { key: i }, option.map((obj, j) => (React.createElement(View, { className: `${prefix}-body-item`, key: j }, obj.text))))))))))));
};
export default Picker;
//# sourceMappingURL=Picker.js.map