import { View } from '@tarojs/components';
import cx from 'classnames';
import React, { useEffect, useMemo, useState } from 'react';
import HuiInput from '../Input';
import HuiIcon from '../Icon';
import HuiButton from '../Button/Button';
import './Search.scss';
const prefix = 'hui-search';
// eslint-disable-next-line @typescript-eslint/no-empty-function
const empty = () => { };
const Search = props => {
    const { searchText, searchIcon = true, clearIcon = true, onlyClick, className = '', style, onInput = empty, onClear, onClick, onSearch, theme = 'light', } = props;
    const [val, setVal] = useState('');
    const allowClear = useMemo(() => clearIcon && props.value, [clearIcon, props.value]);
    const searchBg = useMemo(() => {
        let bgColor = '#fff';
        if (theme === 'dark') {
            bgColor = '#1e1e1e0d';
        }
        return { backgroundColor: bgColor };
    }, [theme]);
    useEffect(() => {
        setVal(props.value || '');
    }, [props.value]);
    return (React.createElement(View, { style: style, className: `${prefix} ${className}`, onClick: e => {
            if (onlyClick && onClick) {
                onClick(e);
            }
        } },
        React.createElement(View, { className: cx(`${prefix}-content`), style: searchBg },
            searchIcon ? (React.createElement(View, { className: cx(`${prefix}-search-icon search`) },
                React.createElement(HuiIcon, { name: '015-searchcircle', color: '#a4a4a4ff', size: 16, style: { display: 'block' } }))) : null,
            React.createElement(View, { className: cx(`${prefix}-input-box`, { 'small-gap': allowClear, 'search-icon': searchIcon }) },
                React.createElement(HuiInput, Object.assign({}, props, { style: { padding: 0, height: '100%', background: 'transparent' }, value: val, onInput: ({ detail: { value, }, }) => {
                        onInput(value);
                    } }))),
            allowClear ? (React.createElement(View, { className: cx(`${prefix}-search-icon clear`), onClick: () => {
                    onInput('');
                    if (onClear) {
                        onClear();
                    }
                } },
                React.createElement(HuiIcon, { name: '005-close2', color: '#1e1e1e40', size: 16, style: { display: 'block' } }))) : null),
        searchText ? (React.createElement(View, { className: cx(`${prefix}-search-text`), onClick: e => {
                if (onSearch) {
                    onSearch(val, e);
                }
            } },
            React.createElement(HuiButton, { type: 'text', size: 'small', radiusType: 'square' }, searchText))) : null));
};
export default Search;
//# sourceMappingURL=Search.js.map