import React, { useState } from 'react';
import { View, Block, Image } from '@tarojs/components';
import Taro from '@tarojs/taro';
import { pxTransform } from '../../utils';
import HuiPopup from '../Popup';
import HuiIcon from '../Icon';
import HuiButton from '../Button';
import HuiImage from '../Image';
import ShareSwiper from './ShareSwiper';
import './Share.scss';
const COLORS = {
    GREEN: '#09BB07',
    ORANGE: '#FF8F33',
};
const LOADER_URL = 'https://r.kezaihui.com/loading-storehome-20191120001.gif';
const HuiShare = props => {
    const { url, loading, multiple = false, visible = false, style, className = '', onClose = () => 0, onRefuseWritePhotosAlbum = () => 0, } = props;
    const [currentPostIndex, setCurrentPostIndex] = useState(0);
    const handleClickSave = () => {
        Taro.getSetting({
            success(res) {
                if (res.authSetting['scope.writePhotosAlbum'] === undefined) {
                    // 未授权过写入相册权限时
                    Taro.authorize({
                        scope: 'scope.writePhotosAlbum',
                        success() {
                            savePostToAlbum();
                        },
                        fail() {
                            Taro.showToast({
                                title: '保存失败',
                            });
                        },
                    });
                }
                else if (!res.authSetting['scope.writePhotosAlbum']) {
                    // 拒绝过写入相册权限时
                    onRefuseWritePhotosAlbum();
                }
                else {
                    // 同意授权时
                    savePostToAlbum();
                }
            },
        });
    };
    const savePostToAlbum = async () => {
        if (!url)
            return;
        await Taro.showLoading({
            title: '保存中…',
            mask: true,
        });
        await Taro.saveImageToPhotosAlbum({
            filePath: multiple ? url === null || url === void 0 ? void 0 : url[currentPostIndex] : url === null || url === void 0 ? void 0 : url[0],
            success: () => {
                setTimeout(() => {
                    Taro.showToast({
                        title: '海报已保存至手机相册',
                        icon: 'success',
                        duration: 2000,
                    });
                }, 100);
            },
            fail: () => {
                setTimeout(() => {
                    Taro.showToast({
                        title: '保存失败',
                        duration: 2000,
                    });
                }, 100);
            },
        });
        await Taro.hideLoading();
    };
    const renderSingleContent = () => (React.createElement(View, { className: 'hui-share-content' }, (url === null || url === void 0 ? void 0 : url[0]) && (React.createElement(HuiImage, { mode: 'aspectFill', src: url === null || url === void 0 ? void 0 : url[0], className: 'hui-share-img', width: 260, height: 360 }))));
    const renderMultipleContent = () => (React.createElement(View, { className: 'hui-share-multiple-content' }, visible && !!url && !!url.filter(v => !!v).length && (React.createElement(ShareSwiper, { urlList: url, handleChange: index => setCurrentPostIndex(index) }))));
    return (React.createElement(View, null,
        React.createElement(HuiPopup, { position: 'bottom', visible: visible, className: className, style: Object.assign({ borderRadius: `${pxTransform(24)} ${pxTransform(24)} 0 0`, overflow: 'hidden' }, style), onClose: onClose },
            React.createElement(View, { className: 'hui-share' },
                React.createElement(View, { className: 'hui-share-header' },
                    React.createElement(HuiIcon, { name: '006-close3', size: 20, color: 'rgba(30, 30, 30, .5)', onClick: onClose })),
                loading ? (React.createElement(View, { className: 'loading-content' },
                    React.createElement(Image, { src: LOADER_URL, className: 'loading-image' }),
                    React.createElement(View, { className: 'loading-tip' }, "\u52A0\u8F7D\u4E2D\u2026"))) : (React.createElement(Block, null, multiple ? renderMultipleContent() : renderSingleContent())),
                React.createElement(View, { className: 'hui-share-btn-group' },
                    React.createElement(HuiButton, { openType: 'share', type: 'text', disabled: loading },
                        React.createElement(Block, null,
                            React.createElement(HuiIcon, { name: '065-wechat', size: 52, color: COLORS.GREEN }),
                            React.createElement(View, { className: 'title' }, "\u63A8\u8350\u597D\u53CB"),
                            React.createElement(View, { className: 'tips' }, "\u53D1\u7ED9\u5FAE\u4FE1\u597D\u53CB"))),
                    React.createElement(HuiButton, { type: 'text', onClick: handleClickSave, disabled: loading },
                        React.createElement(Block, null,
                            React.createElement(HuiIcon, { name: '101-downfill', size: 52, color: COLORS.ORANGE }),
                            React.createElement(View, { className: 'title' }, "\u4FDD\u5B58\u6D77\u62A5"),
                            React.createElement(View, { className: 'tips' }, "\u53D1\u5230\u5FAE\u4FE1\u670B\u53CB\u5708"))))))));
};
export default HuiShare;
//# sourceMappingURL=Share.js.map