import React from 'react';
import { View } from '@tarojs/components';
import { pxTransform } from '../../utils';
const DEFAULT_AVATAR_SIZE = 80;
const DEFAULT_AVATAR_SHAPE = 'square';
const DEFAULT_TITLE_WIDTH = '50%';
const DEFAULT_PARAGRAPH_ROWS = 3;
const DEFAULT_PARAGRAPH_WIDTH = ['100%', '100%', '70%'];
const HuiSkeleton = props => {
    var _a, _b, _c, _d;
    const { type, avatar, title, paragraph, className = '', style } = props;
    const avartarSize = typeof avatar === 'object'
        ? (_a = avatar.size) !== null && _a !== void 0 ? _a : DEFAULT_AVATAR_SIZE : DEFAULT_AVATAR_SIZE;
    const avatarShap = typeof avatar === 'object'
        ? (_b = avatar.shape) !== null && _b !== void 0 ? _b : DEFAULT_AVATAR_SHAPE : DEFAULT_AVATAR_SHAPE;
    const titleWidth = typeof title === 'object'
        ? (_c = title.width) !== null && _c !== void 0 ? _c : DEFAULT_TITLE_WIDTH : DEFAULT_TITLE_WIDTH;
    const paragraphRows = typeof paragraph === 'object'
        ? (_d = paragraph.rows) !== null && _d !== void 0 ? _d : DEFAULT_PARAGRAPH_ROWS : DEFAULT_PARAGRAPH_ROWS;
    const paragraphWidth = typeof paragraph === 'object'
        ? paragraph.width || DEFAULT_PARAGRAPH_WIDTH
        : DEFAULT_PARAGRAPH_WIDTH;
    const paragraphs = Array(paragraphRows).fill(0)
        .map((_, index) => ({ width: paragraphWidth[index] || '100%' }))
        .map(({ width }) => ({
        width: typeof width === 'number'
            ? pxTransform(width)
            : width,
    }));
    const hasAvatar = !!avatar;
    const hasTitle = !!title;
    const hasParagraph = !!paragraph;
    return (React.createElement(View, { style: style, className: `hui-skeleton ${type} ${className}` },
        hasAvatar && (React.createElement(View, { className: `hui-skeleton-avatar ${avatarShap}`, style: {
                width: type === 'vertical' ? '100%' : pxTransform(avartarSize),
                height: pxTransform(avartarSize),
            } })),
        (hasTitle || hasParagraph) && (React.createElement(View, { className: `hui-skeleton-content ${hasAvatar ? 'has-avatar' : ''}` },
            hasTitle && (React.createElement(View, { className: 'hui-skeleton-title', style: {
                    width: typeof titleWidth === 'number'
                        ? pxTransform(titleWidth)
                        : titleWidth,
                } })),
            hasParagraph && (React.createElement(View, { className: 'hui-skeleton-paragraph-content' }, paragraphs.map(({ width }, index) => (React.createElement(View, { key: index, className: 'hui-skeleton-paragraph', style: { width } })))))))));
};
HuiSkeleton.defaultProps = {
    type: 'horizontal',
    title: true,
    avatar: true,
    paragraph: true,
};
export default HuiSkeleton;
//# sourceMappingURL=index.js.map