/* eslint-disable @typescript-eslint/no-empty-function */
import React, { useState } from 'react';
import { View, Input } from '@tarojs/components';
import { pxTransform } from '../../utils';
import Icon from '../Icon/Icon';
function addNum(num1, num2) {
    let sq1, sq2;
    try {
        sq1 = num1.toString().split('.')[1].length;
    }
    catch (e) {
        sq1 = 0;
    }
    try {
        sq2 = num2.toString().split('.')[1].length;
    }
    catch (e) {
        sq2 = 0;
    }
    const m = Math.pow(10, Math.max(sq1, sq2));
    return (Math.round(num1 * m) + Math.round(num2 * m)) / m;
}
// 格式化数字，处理01变成1,并且不处理1. 这种情况
function parseValue(num) {
    if (num === '')
        return '0';
    const numStr = num.toString();
    if (numStr.indexOf('0') === 0 && numStr.indexOf('.') === -1) {
        // 处理01变成1,并且不处理1.
        return parseFloat(num).toString();
    }
    return num.toString();
}
const Stepper = (props) => {
    const [scaleAnimation, setScaleAnimation] = useState({
        plus: false,
        minus: false,
    });
    const { style, className = '', disabled = false, disabledInput = false, value = 0, type = 'number', width = 0, min = 0, max = Infinity, hideMinus = false, step = 1, onChange = () => { }, onBlur = () => { }, } = props;
    const handleClick = (clickType, e) => {
        const lowThanMin = clickType === 'minus' && value <= min;
        const overThanMax = clickType === 'plus' && value >= max;
        // 极值判断
        if (lowThanMin || overThanMax || disabled) {
            setScaleAnimation({
                plus: false,
                minus: false,
            });
            const deltaValue = clickType === 'minus' ? -step : step;
            const errorValue = addNum(Number(value), deltaValue);
            if (disabled) {
                handleError({
                    type: 'DISABLED',
                    errorValue,
                });
            }
            else {
                handleError({
                    type: lowThanMin ? 'LOW' : 'OVER',
                    errorValue,
                });
            }
            return;
        }
        // 正常累加
        const deltaValue = clickType === 'minus' ? -step : step;
        if (deltaValue > 0) {
            setScaleAnimation({
                plus: true,
                minus: false,
            });
        }
        else {
            setScaleAnimation({
                plus: false,
                minus: true,
            });
        }
        if (!disabled) {
            setTimeout(() => {
                setScaleAnimation({
                    plus: false,
                    minus: false,
                });
            }, 200);
        }
        let newValue = addNum(Number(value), deltaValue);
        newValue = Number(handleValue(newValue));
        onChange(newValue, e);
    };
    const handleValue = (val) => {
        let resultValue = val === '' ? min : val;
        // 此处不能使用 Math.max，会是字符串变数字，并丢失 .
        if (resultValue > max) {
            resultValue = max;
            handleError({
                type: 'OVER',
                errorValue: resultValue,
            });
        }
        if (resultValue < min) {
            resultValue = min;
            handleError({
                type: 'LOW',
                errorValue: resultValue,
            });
        }
        if (resultValue && !Number(resultValue)) {
            resultValue = parseFloat(resultValue.toString()) || min;
            handleError({
                type: 'OVER',
                errorValue: resultValue,
            });
        }
        resultValue = parseValue(resultValue.toString());
        return resultValue;
    };
    const handleInput = (e) => {
        const { value: val } = e.target;
        if (disabled)
            return;
        const newValue = handleValue(val);
        onChange(Number(newValue), e);
    };
    const handleBlur = (event) => onBlur && onBlur(event);
    const handleError = (errorValue) => {
        if (!props.onErrorInput) {
            return;
        }
        props.onErrorInput(errorValue);
    };
    const inputStyle = {
        width: width ? `${pxTransform(width)}` : '',
    };
    const inputValue = Number(handleValue(value));
    const minusBtnCls = `hui-stepper-btn minus ${inputValue <= min || disabled ? 'hui-stepper-disabled' : ''}`;
    const plusBtnCls = `hui-stepper-btn plus ${inputValue >= max || disabled ? 'hui-stepper-disabled' : ''}`;
    const initHideMinusAndInput = `${hideMinus && value === min ? 'hide' : ''}`;
    const disableInputFormat = hideMinus ? !!(initHideMinusAndInput || disabledInput) : disabledInput;
    return (React.createElement(View, { className: `hui-stepper ${className} ${initHideMinusAndInput}`, style: style },
        React.createElement(View, { className: minusBtnCls, onClick: e => handleClick('minus', e) },
            React.createElement(View, { className: `btn ${scaleAnimation.minus ? 'active' : ''}` },
                React.createElement(Icon, { name: '008-remove', size: 20, style: {
                        display: 'block',
                        textAlign: 'center',
                    } }))),
        React.createElement(Input, { className: 'hui-stepper-input', style: inputStyle, type: type, value: String(inputValue), disabled: disableInputFormat || disabled, onInput: e => handleInput(e), onBlur: e => handleBlur(e) }),
        React.createElement(View, { className: plusBtnCls, onClick: e => handleClick('plus', e) },
            React.createElement(View, { className: `btn ${scaleAnimation.plus ? 'active' : ''}` },
                React.createElement(Icon, { name: '007-add', size: 20, style: {
                        display: 'block',
                        textAlign: 'center',
                    } })))));
};
export default Stepper;
//# sourceMappingURL=index.js.map