var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useCallback, useEffect, useRef, useState } from 'react';
import cx from 'classnames';
import Taro from '@tarojs/taro';
import { ScrollView, View } from '@tarojs/components';
import { selectorQueryClientRect, } from '../../utils';
import HuiIcon from '../Icon/Icon';
import HuiSticky from '../Sticky/Sticky';
const defaultProps = {
    onChange: () => undefined,
};
const HuiTabs = props => {
    const { active, scroll = false, animated = false, smile = false, shadow = true, onChange = defaultProps.onChange, indicatorColor = '', sticky = false, offsetTop = 0, children, style, className = '' } = props, rest = __rest(props
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    , ["active", "scroll", "animated", "smile", "shadow", "onChange", "indicatorColor", "sticky", "offsetTop", "children", "style", "className"]);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const tabsRef = useRef();
    const tabsInfos = useRef([]);
    const tabsWidth = useRef(0);
    const [tabs, setTabs] = useState([]);
    const [activeTabInfo, setActiveTabInfo] = useState({ width: 0, left: 0 });
    const [tabsWrapperScrollLeft, setTabsWrapperScrollLeft] = useState(0);
    useEffect(() => {
        Taro.nextTick(async () => {
            var _a;
            if (tabs.length <= 0 || !tabsRef.current) {
                return;
            }
            const tabsItemEle = (_a = tabsRef.current) === null || _a === void 0 ? void 0 : _a.childNodes;
            tabsInfos.current = [];
            for (let i = 0; tabsItemEle && i < tabsItemEle.length; i++) {
                if (tabsItemEle[i].childNodes[0] && tabsItemEle[i].childNodes[0].childNodes[0]) {
                    const res = await selectorQueryClientRect(`#${tabsItemEle[i].childNodes[0].childNodes[0].uid}`);
                    tabsInfos.current.push(res);
                }
            }
            const res = await selectorQueryClientRect(`#${tabsRef.current.uid}`);
            tabsWidth.current = res.width;
            updateActiveTabInfo();
        });
    }, [tabs]);
    const updateActiveTabInfo = useCallback(() => {
        if (!tabs) {
            return;
        }
        let index = active;
        if (typeof active === 'string') {
            index = tabs.findIndex(t => t.name === active);
        }
        const activeRes = tabsInfos.current[index];
        if (!activeRes) {
            return;
        }
        setActiveTabInfo({
            left: activeRes.left,
            width: activeRes.width,
        });
        if (scroll) {
            setTabsWrapperScrollLeft(activeRes.left + activeRes.width / 2 - tabsWidth.current / 2);
        }
    }, [active, scroll, tabs]);
    useEffect(() => {
        updateActiveTabInfo();
    }, [updateActiveTabInfo]);
    const handleUpdateParent = (i) => tabValue => {
        setTabs(t => {
            const newTab = t.slice();
            newTab[i] = tabValue;
            if (!newTab[i].name) {
                newTab[i].name = i;
            }
            return newTab;
        });
    };
    const handleClickTabs = (name) => {
        onChange(name);
    };
    const getChildren = () => {
        const fn = (child, index) => React.cloneElement(child, {
            updateParent: handleUpdateParent(index),
            name: child.props.name || index,
            active,
            animated,
        });
        return (children && React.Children.map(children, fn)) || null;
    };
    const tabsSize = React.Children.count(children);
    const getTabsIndicator = () => (smile ? (React.createElement(View, { className: 'tabs-indicator-smile', style: {
            left: activeTabInfo.left + activeTabInfo.width / 2,
            color: indicatorColor,
        } },
        React.createElement(HuiIcon, { name: '010-choose', size: 18 }))) : (React.createElement(View, { className: 'tabs-indicator', style: {
            width: activeTabInfo.width,
            left: activeTabInfo.left,
            background: indicatorColor,
        } })));
    const getTabsItem = (tab) => (smile ? (React.createElement(View, { className: 'tabs-title-smile' },
        React.createElement(View, { className: 'title', style: { color: tab.name === active ? indicatorColor : '' } }, tab.title),
        React.createElement(View, { className: 'sub-title', style: { color: tab.name === active ? indicatorColor : '' } }, tab.subTitle))) : (React.createElement(View, { className: 'tabs-title' }, tab.title)));
    const tabsContent = (React.createElement(View, { ref: tabsRef, className: cx('hui-tabs-wrapper', { scrollable: scroll }, { normal: !scroll }, { 'no-shadow': !shadow }) },
        tabs.map(tab => (React.createElement(View, { key: `${tab.name}`, className: `tabs-item length-${tabsSize}`, onClick: () => handleClickTabs(tab.name) },
            React.createElement(View, { className: cx('tabs-item-wrapper', { active: active === tab.name }) }, getTabsItem(tab))))),
        getTabsIndicator()));
    const activeTabIndex = tabs.findIndex(t => t.name === active);
    const huiTabsBar = (React.createElement(View, Object.assign({}, rest, { className: cx('hui-tabs-bar', { 'no-shadow': !shadow }) }), scroll ? (React.createElement(ScrollView, { enhanced: true, showScrollbar: false, scrollX: scroll, scrollLeft: tabsWrapperScrollLeft, scrollWithAnimation: true, className: 'scrollable-tabs-wrapper' }, tabsContent)) : (tabsContent)));
    return (React.createElement(View, { className: `hui-tabs ${className}`, style: style },
        sticky ? (React.createElement(HuiSticky, { offsetTop: offsetTop }, huiTabsBar)) : (huiTabsBar),
        React.createElement(View, { className: 'hui-tabs-panel-wrapper' },
            React.createElement(View, { className: cx('hui-tabs-panel', { 'switch-with-animation': animated }), style: animated ? { transform: `translateX(-${100 * activeTabIndex}%)` } : {} }, getChildren()))));
};
export default HuiTabs;
//# sourceMappingURL=Tabs.js.map