import React, { useRef, useState, useEffect } from 'react';
import { View, Block } from '@tarojs/components';
import dayjs from 'dayjs';
import cx from 'classnames';
import TimerItem from './item';
import { parseDurationToTime, getTimerFormatSeparator } from '../../utils';
import './Timer.scss';
const defaultProps = {
    onFinished: () => void 0,
    onChange: () => void 0,
};
const HuiTimer = props => {
    const { className = '', style, time = 0, startTime = '', isCard = false, isShowDay = false, isCountDown = true, format = 'DD天 HH:mm:ss', onFinished = defaultProps.onFinished, onChange = defaultProps.onChange, } = props;
    const timeoutId = useRef(null);
    const [remainingTime, setRemainingTime] = useState({
        days: '00',
        hours: '00',
        minutes: '00',
        seconds: '00',
    });
    const countDownMilliseconds = Math.max(0, time);
    const endTime = dayjs().add(countDownMilliseconds, 'ms');
    const currentTime = dayjs();
    const formatSeparator = getTimerFormatSeparator(format);
    const clear = () => {
        if (!timeoutId.current) {
            return;
        }
        clearTimeout(timeoutId.current);
        timeoutId.current = null;
    };
    const getDisplayTime = remain => ({
        days: parseDurationToTime(remain, 'DD'),
        hours: parseDurationToTime(remain, 'HH'),
        minutes: parseDurationToTime(remain, 'mm'),
        seconds: parseDurationToTime(remain, 'ss'),
    });
    const handleChange = remain => {
        setRemainingTime(getDisplayTime(remain));
        onChange(getDisplayTime(remain));
    };
    const countDown = () => {
        clear();
        const nowTime = dayjs();
        const remain = Math.max(endTime.diff(nowTime), 0);
        if (remain <= 0) {
            onFinished();
            return;
        }
        handleChange(remain);
        timeoutId.current = setTimeout(countDown, 1000);
    };
    const forward = () => {
        clear();
        const nowTime = dayjs();
        const previousTime = startTime ? dayjs(startTime) : currentTime;
        const remain = Math.max(nowTime.diff(previousTime), 0);
        handleChange(remain);
        timeoutId.current = setTimeout(forward, 1000);
    };
    useEffect(() => {
        if (isCountDown && time > 0) {
            countDown();
        }
        else {
            forward();
        }
        return () => clear();
    }, [time, isCountDown]);
    return (React.createElement(View, { style: style, className: cx(`hui-timer ${className}`, { 'card-timer': isCard }) },
        isShowDay && formatSeparator.day && (React.createElement(TimerItem, { num: remainingTime.days, separator: isCard ? formatSeparator.day : React.createElement(Block, null,
                formatSeparator.day,
                "\u00A0") })),
        React.createElement(TimerItem, { num: remainingTime.hours, separator: formatSeparator.hour }),
        React.createElement(TimerItem, { num: remainingTime.minutes, separator: formatSeparator.minute }),
        React.createElement(TimerItem, { num: remainingTime.seconds, separator: formatSeparator.second })));
};
export default HuiTimer;
//# sourceMappingURL=Timer.js.map