/* eslint-disable no-underscore-dangle */
import React from 'react';
import { View, Text } from '@tarojs/components';
import cx from 'classnames';
import HuiIcon from '../Icon/Icon';
import { ToastTypeEnum } from './constants';
const DefaultIconName = new Map([
    [ToastTypeEnum.SUCCESS, '003-right'],
    [ToastTypeEnum.WARNING, '002-warnings'],
    [ToastTypeEnum.FAIL, '001-close'],
]);
export default class Index extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            _visible: this.props.visible,
        };
        // eslint-disable-next-line react/sort-comp
        this._timer = null;
    }
    close() {
        const { _visible } = this.state;
        if (_visible) {
            this.setState({
                _visible: false,
            });
            this.clearTimer();
        }
    }
    clearTimer() {
        if (this._timer) {
            clearTimeout(this._timer);
            this._timer = null;
        }
    }
    makeTimer(duration) {
        if (duration === 0)
            return;
        this._timer = setTimeout(() => {
            this.close();
        }, duration);
    }
    componentWillReceiveProps(nextProps) {
        const { visible, duration } = nextProps;
        if (!visible) {
            this.close();
            return;
        }
        if (!this.state._visible) {
            this.setState({
                _visible: true,
            });
        }
        else {
            this.clearTimer();
        }
        this.makeTimer(duration || 0);
    }
    // eslint-disable-next-line class-methods-use-this
    getIconName(type, customIcon) {
        return DefaultIconName.get(type) || customIcon;
    }
    render() {
        const { type, title, icon } = this.props;
        return this.state._visible ? (React.createElement(View, { className: cx('hui-toast-box', { mask: this.props.mask }) },
            React.createElement(View, { className: 'toast' },
                type !== ToastTypeEnum.TEXT && (React.createElement(View, { className: 'icon' }, type !== ToastTypeEnum.TEXT
                    && React.createElement(HuiIcon, { name: this.getIconName(type, icon), size: 36 }))),
                React.createElement(Text, { className: 'text' }, title)))) : null;
    }
}
Index.defaultProps = {
    duration: 1500,
    visible: false,
    mask: false,
    icon: '',
};
//# sourceMappingURL=Toast.js.map