import React from 'react';
import { View } from '@tarojs/components';
import HuiIcon from '../Icon/Icon';
import './Tooltip.scss';
const placementCls = {
    top: 'top',
    topRight: 'top-right',
    topLeft: 'top-left',
    bottom: 'bottom',
    bottomRight: 'bottom-right',
    bottomLeft: 'bottom-left',
    left: 'left',
    right: 'right',
};
export default class Tooltip extends React.Component {
    constructor() {
        super(...arguments);
        this.timer = null;
        this.handleClose = () => {
            const { onClose } = this.props;
            onClose && onClose();
        };
        this.restartTimer = () => {
            const { duration } = this.props;
            this.clearTimer();
            this.makeTimer(duration || 0);
        };
    }
    componentWillReceiveProps(nextProps) {
        const { visible } = nextProps;
        const { closable } = this.props;
        if (visible === this.props.visible)
            return;
        if (!visible) {
            this.close();
            return;
        }
        if (closable)
            return;
        this.restartTimer();
    }
    close() {
        const { onClose } = this.props;
        onClose && onClose();
        this.clearTimer();
    }
    clearTimer() {
        if (this.timer) {
            clearTimeout(this.timer);
            this.timer = null;
        }
    }
    makeTimer(duration) {
        if (duration === 0)
            return;
        this.timer = setTimeout(() => {
            this.close();
        }, duration);
    }
    render() {
        const { children, content, placement = 'top', containerStyle, popStyle, visible, closable, className = '', } = this.props;
        return (React.createElement(View, { className: `hui-tooltip-container ${className}`, style: containerStyle },
            children,
            visible && React.createElement(View, { className: `hui-tooltip ${placementCls[placement]}`, style: popStyle },
                React.createElement(View, { className: 'hui-tooltip-content' }, content),
                React.createElement(View, { className: 'hui-tooltip-arrow' }),
                closable && React.createElement(View, { className: 'hui-tooltip-close', onClick: this.handleClose },
                    React.createElement(HuiIcon, { name: '006-close3', color: '#fff', size: 10 })))));
    }
}
Tooltip.defaultProps = {
    duration: 1000,
    visible: false,
    placement: 'top',
};
//# sourceMappingURL=Tooltip.js.map