import React from 'react';
import { BaseEventOrig } from '@tarojs/components';
import { ScrollViewProps } from '@tarojs/components/types/ScrollView';
interface HuiNavBarProps {
    /**
     * 是否为透明背景，使用透明背景时需要配合ScrollView的onScroll事件来改变透明度，
     * onScroll事件用getOpacityChangeHandlerGenerator生成
     * */
    transparent?: boolean;
    /** 标题 */
    title?: React.ReactNode;
    /** 主题色，需要和页面配置的navigationBarTextStyle保持一致 */
    theme?: 'white' | 'black';
    /** 是否隐藏返回上一页按钮 */
    hideBack?: boolean;
    /** 是否展示回首页按钮 */
    showHome?: boolean;
    /** 自定义按钮，使用自定义按钮时返回和首页不会展示 */
    button?: React.ReactNode;
    /** 背景透明度 */
    opacity?: number;
    style?: React.CSSProperties;
    className?: string;
    /** 首页地址，默认为/pages/Index/Index */
    homepagePath?: string;
    /** 返回上一页的钩子函数，返回false或者Promise.resolve(false)跳转首页失败 */
    beforeNavBack?: () => boolean | Promise<boolean>;
    /** 返回首页前的钩子函数，返回false或者Promise.resolve(false)跳转首页失败 */
    beforeBackToHome?: () => boolean | Promise<boolean>;
}
declare const HuiNavBar: React.FC<HuiNavBarProps>;
export declare const getOpacityChangeHandlerGenerator: (e: BaseEventOrig<ScrollViewProps.onScrollDetail>, cb: (opacity: number) => void, opacityChangeScrollOption?: {
    /** 从距离页面顶部{upper}px处opacity开始变化 */
    upper?: number;
    /** 在{range}px范围内opacity从0变化到100% */
    range?: number;
}) => void;
export default HuiNavBar;
