import { ViewProps } from '@tarojs/components/types/View';
import React from 'react';
interface HuiSelectOption {
    /** 选项名 */
    label: string;
    /** 选项值 */
    value: string | number;
    /** 是否禁用 */
    disabled?: boolean;
    /** 子选项 */
    children?: HuiSelectOption[];
}
export interface HuiSelectProps extends ViewProps {
    /** 是否展示 */
    visible: boolean;
    /** 标题 */
    title?: React.ReactNode;
    /** 关闭回调 */
    onClose?(): void;
    /** 菜单层级，默认为2 */
    level?: 1 | 2;
    /** 是否支持多选, 默认为false，即单选 */
    multiSelect?: boolean;
    /** 是否展示徽标，level为2 且 multiSelect为true时生效 */
    showBadge?: boolean;
    /** 选项 */
    options: HuiSelectOption[];
    /**
     * 选中值
     * 一级菜单时为选中项的value
     * 二级菜单时为所有子选项的value
     * */
    value?: (string | number)[];
    /** 确认按钮文字 */
    confirmText?: string;
    /** 主题色设置 */
    color?: string;
    /** 开启异步加载画面 */
    loading?: boolean;
    /** hui-select-body的高度，默认由内容撑开，可以选择设置 */
    contentHeight?: number;
    style?: React.CSSProperties;
    className?: string;
    /** 选中选项时的回调 */
    onChange?(v: (number | string)[]): void;
    /** level为2时，切换侧边菜单时的回调 */
    onChangeSideMenu?(v: number | string): void;
    /** 确认回调 */
    onConfirm?(v: (number | string)[]): void;
}
declare const Select: React.FC<HuiSelectProps>;
export default Select;
