import React from 'react';
import { ButtonProps } from '@tarojs/components/types/Button';
import { BaseEventOrig } from '@tarojs/components/types/common';
import './LoginWidget.scss';
/**
 * 通用的登录逻辑组件
 * 预设用于绑定手机号完成身份验证的场景
 *
 * 对于这种场景，或许用户身份的手段有两种（暂时不考虑获取头像昵称信息）
 * - 静默使用code换openId（一定条件下可以获得unionId）
 * - 用户授权手机号
 *
 * 手机号作为用户身份的唯一标识可以更方便跨平台使用、将openId/unionId与手机号关联可以实现静默登录提升用户体验
 *
 * 因此组件的基本逻辑如下
 * - 首先利用code获取用户身份，如果用户已授权手机号则登录逻辑全部完成
 * - 如果使用code获取到的用于身份未授权手机号，则展示授权手机号的按钮提示用户授权手机号
 *
 * 对应状态参见Props
 */
export interface LoginWidgetProps {
    isLogined: boolean;
    onLogined: () => void;
    dispatchLogin: (code: string) => void;
    loginLoading: string;
    loginSuccessTip: string;
    dispatchGetPhone: (encryptedData: string, iv: string) => void;
    getPhoneLoading: string;
    getPhoneSuccessTip: string;
    isSettled: boolean;
    onSettled: () => void;
    children: React.ReactNode;
}
export default class LoginWidget extends React.Component<LoginWidgetProps> {
    componentDidMount(): void;
    /**
     * 初始化逻辑
     * 注意在settled状态下会同时出发onLogin和onSettled，因为settled时isLogined确实满足
     */
    handleInit(): void;
    handleLogin: () => Promise<void>;
    handleBind: (event: BaseEventOrig<ButtonProps.onGetPhoneNumberEventDetail>) => Promise<void>;
    handleIfLogined(): void;
    handleIfSettled(): void;
    render(): JSX.Element;
}
