import Taro from '@tarojs/taro';
import dayjs from 'dayjs';
import 'dayjs/plugin/duration';
import { DESIGN_WIDTH } from './constant';
export const pxTransform = (size) => Taro.pxTransform(size, DESIGN_WIDTH);
export const selectorQueryClientRect = (selector) => new Promise(resolve => {
    const query = Taro.createSelectorQuery();
    query
        .select(selector)
        .boundingClientRect((res) => {
        resolve((res === null || res === void 0 ? void 0 : res[0]) || res);
    })
        .exec();
});
export const selectorQueryScrollOffset = (selector) => new Promise(resolve => {
    const query = Taro.createSelectorQuery();
    query
        .select(selector)
        .scrollOffset((res) => {
        resolve(res);
    })
        .exec();
});
const hexToRgb = (hex) => {
    const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
    return result
        ? {
            r: parseInt(result[1], 16),
            g: parseInt(result[2], 16),
            b: parseInt(result[3], 16),
        }
        : null;
};
/**
 * 返回带透明度的rgba色值的字符串
 * @param {16进制色值} hexColor
 * @param {透明度} opacity
 */
export const addOpacityToHexColor = (hexColor, opacity = 1) => {
    const rgb = hexToRgb(hexColor);
    if (!rgb) {
        return '';
    }
    return `rgba(${rgb.r}, ${rgb.g}, ${rgb.b}, ${opacity})`;
};
/**
 * 返回字符|数字|最大值+
 * @param value
 * @param maxValue 最大值
 */
export const formatValue = (value, maxValue) => {
    if (value === '' || value === null || value === undefined)
        return '';
    const numValue = +value;
    if (Number.isNaN(numValue)) {
        return value;
    }
    return numValue > maxValue ? `${maxValue}+` : numValue;
};
/**
 * 将时长转换成格式
 * @param d 时长
 * @param format 格式
 */
export const parseDurationToTime = (d, format) => {
    const duration = dayjs.duration(d);
    if (format.indexOf('DD') !== -1) {
        let days = String(Math.floor(duration.asDays()));
        if (days.length < 2) {
            days = '0'.concat(days);
        }
        format = format.replace('DD', days);
    }
    if (format.indexOf('HH') !== -1) {
        let hours = String(duration.hours());
        if (hours.length < 2) {
            hours = '0'.concat(hours);
        }
        format = format.replace('HH', hours);
    }
    if (format.indexOf('mm') !== -1) {
        let minutes = String(duration.minutes());
        if (minutes.length < 2) {
            minutes = '0'.concat(minutes);
        }
        format = format.replace('mm', minutes);
    }
    if (format.indexOf('ss') !== -1) {
        let seconds = String(duration.seconds());
        if (seconds.length < 2) {
            seconds = '0'.concat(seconds);
        }
        format = format.replace('ss', seconds);
    }
    return format;
};
/**
 * 获取格式中的分隔符
 * @param format 格式
 */
export const getTimerFormatSeparator = (format = 'HH:mm:ss') => {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    return ({
        day: (_b = (_a = format.split('DD')) === null || _a === void 0 ? void 0 : _a[1]) === null || _b === void 0 ? void 0 : _b[0],
        hour: (_d = (_c = format.split('HH')) === null || _c === void 0 ? void 0 : _c[1]) === null || _d === void 0 ? void 0 : _d[0],
        minute: (_f = (_e = format.split('mm')) === null || _e === void 0 ? void 0 : _e[1]) === null || _f === void 0 ? void 0 : _f[0],
        second: (_h = (_g = format.split('ss')) === null || _g === void 0 ? void 0 : _g[1]) === null || _h === void 0 ? void 0 : _h[0],
    });
};
//# sourceMappingURL=index.js.map