import React from 'react';
import { Button, Block } from '@tarojs/components';
import Taro from '@tarojs/taro';
import errorParser from '../../utils/errorParser';
import SimpleHint from '../../services/SimpleHint';
import './LoginWidget.scss';
export default class LoginWidget extends React.Component {
    constructor() {
        super(...arguments);
        this.handleLogin = async () => {
            const { code } = await Taro.login();
            try {
                SimpleHint.startLoading(this.props.loginLoading);
                await this.props.dispatchLogin(code);
                this.handleIfLogined();
                this.handleIfSettled();
                SimpleHint.stopLoading();
            }
            catch (e) {
                SimpleHint.stopLoading();
                SimpleHint.error(errorParser(e));
            }
        };
        this.handleBind = async (event) => {
            const { encryptedData, iv } = event.detail;
            if (!encryptedData || !iv) {
                return;
            }
            try {
                SimpleHint.startLoading(this.props.getPhoneLoading);
                await this.props.dispatchGetPhone(encryptedData, iv);
                this.handleIfSettled();
                SimpleHint.stopLoading();
            }
            catch (e) {
                SimpleHint.stopLoading();
                SimpleHint.error(errorParser(e));
            }
        };
    }
    componentDidMount() {
        this.handleInit();
    }
    /**
     * 初始化逻辑
     * 注意在settled状态下会同时出发onLogin和onSettled，因为settled时isLogined确实满足
     */
    handleInit() {
        if (this.props.isLogined) {
            this.props.onLogined();
        }
        else {
            this.handleLogin();
        }
        if (this.props.isSettled) {
            this.props.onSettled();
        }
    }
    handleIfLogined() {
        if (this.props.isLogined) {
            if (this.props.loginSuccessTip) {
                SimpleHint.success(this.props.loginSuccessTip);
            }
            this.props.onLogined();
        }
    }
    handleIfSettled() {
        if (this.props.isSettled) {
            if (this.props.getPhoneSuccessTip) {
                SimpleHint.success(this.props.getPhoneSuccessTip);
            }
            this.props.onSettled();
        }
    }
    render() {
        return (this.props.isSettled ? React.createElement(Block, null) : React.createElement(Button, { plain: true, openType: 'getPhoneNumber', className: 'login-widget button-reset', onGetPhoneNumber: this.handleBind }, this.props.children));
    }
}
//# sourceMappingURL=LoginWidget.js.map